@@ -17,21 +17,29 @@
 
 from __future__ import unicode_literals
 
-from . import (lang_AM, lang_AR, lang_CZ, lang_DE, lang_DK, lang_EN,
-               lang_EN_IN, lang_EO, lang_ES, lang_ES_CO, lang_ES_NI,
-               lang_ES_VE, lang_FA, lang_FI, lang_FR, lang_FR_BE, lang_FR_CH,
-               lang_FR_DZ, lang_HE, lang_HU, lang_ID, lang_IT, lang_JA,
-               lang_KN, lang_KO, lang_KZ, lang_LT, lang_LV, lang_NL, lang_NO,
-               lang_PL, lang_PT, lang_PT_BR, lang_RO, lang_RU, lang_SL,
-               lang_SR, lang_SV, lang_TE, lang_TG, lang_TH, lang_TR, lang_UK,
-               lang_VI)
+from . import (lang_AM, lang_AR, lang_AZ, lang_BE, lang_BN, lang_CA, lang_CE,
+               lang_CS, lang_CY, lang_DA, lang_DE, lang_EN, lang_EN_IN,
+               lang_EN_NG, lang_EO, lang_ES, lang_ES_CO, lang_ES_CR,
+               lang_ES_GT, lang_ES_NI, lang_ES_VE, lang_FA, lang_FI, lang_FR,
+               lang_FR_BE, lang_FR_CH, lang_FR_DZ, lang_HE, lang_HU, lang_ID,
+               lang_IS, lang_IT, lang_JA, lang_KN, lang_KO, lang_KZ, lang_LT,
+               lang_LV, lang_NL, lang_NO, lang_PL, lang_PT, lang_PT_BR,
+               lang_RO, lang_RU, lang_SK, lang_SL, lang_SR, lang_SV, lang_TE,
+               lang_TET, lang_TG, lang_TH, lang_TR, lang_UK, lang_VI)
 
 CONVERTER_CLASSES = {
     'am': lang_AM.Num2Word_AM(),
     'ar': lang_AR.Num2Word_AR(),
-    'cz': lang_CZ.Num2Word_CZ(),
+    'az': lang_AZ.Num2Word_AZ(),
+    'be': lang_BE.Num2Word_BE(),
+    'bn': lang_BN.Num2Word_BN(),
+    'ca': lang_CA.Num2Word_CA(),
+    'ce': lang_CE.Num2Word_CE(),
+    'cs': lang_CS.Num2Word_CS(),
+    'cy': lang_CY.Num2Word_CY(),
     'en': lang_EN.Num2Word_EN(),
     'en_IN': lang_EN_IN.Num2Word_EN_IN(),
+    'en_NG': lang_EN_NG.Num2Word_EN_NG(),
     'fa': lang_FA.Num2Word_FA(),
     'fr': lang_FR.Num2Word_FR(),
     'fr_CH': lang_FR_CH.Num2Word_FR_CH(),
@@ -42,6 +50,8 @@ CONVERTER_CLASSES = {
     'eo': lang_EO.Num2Word_EO(),
     'es': lang_ES.Num2Word_ES(),
     'es_CO': lang_ES_CO.Num2Word_ES_CO(),
+    'es_CR': lang_ES_CR.Num2Word_ES_CR(),
+    'es_GT': lang_ES_GT.Num2Word_ES_GT(),
     'es_NI': lang_ES_NI.Num2Word_ES_NI(),
     'es_VE': lang_ES_VE.Num2Word_ES_VE(),
     'id': lang_ID.Num2Word_ID(),
@@ -54,11 +64,12 @@ CONVERTER_CLASSES = {
     'pl': lang_PL.Num2Word_PL(),
     'ro': lang_RO.Num2Word_RO(),
     'ru': lang_RU.Num2Word_RU(),
+    'sk': lang_SK.Num2Word_SK(),
     'sl': lang_SL.Num2Word_SL(),
     'sr': lang_SR.Num2Word_SR(),
     'sv': lang_SV.Num2Word_SV(),
     'no': lang_NO.Num2Word_NO(),
-    'dk': lang_DK.Num2Word_DK(),
+    'da': lang_DA.Num2Word_DA(),
     'pt': lang_PT.Num2Word_PT(),
     'pt_BR': lang_PT_BR.Num2Word_PT_BR(),
     'he': lang_HE.Num2Word_HE(),
@@ -70,7 +81,9 @@ CONVERTER_CLASSES = {
     'nl': lang_NL.Num2Word_NL(),
     'uk': lang_UK.Num2Word_UK(),
     'te': lang_TE.Num2Word_TE(),
-    'hu': lang_HU.Num2Word_HU()
+    'tet': lang_TET.Num2Word_TET(),
+    'hu': lang_HU.Num2Word_HU(),
+    'is': lang_IS.Num2Word_IS(),
 }
 
 CONVERTES_TYPES = ['cardinal', 'ordinal', 'ordinal_num', 'year', 'currency']
@@ -90,7 +103,7 @@ def num2words(number, ordinal=False, lang='en', to='cardinal', **kwargs):
 
     # backwards compatible
     if ordinal:
-        return converter.to_ordinal(number)
+        to = 'ordinal'
 
     if to not in CONVERTES_TYPES:
         raise NotImplementedError()
